#include "board.h"
#include "fsl_debug_console.h"
#include "fsl_gpio.h"
#include "pin_mux.h"
#include "ff.h"
#include "diskio.h" 
#include "fsl_sdspi_disk.h"

uint8_t TestBuffer[2048];

__asm void Delay_ms(unsigned int nCount)
{
0
		ldr  r1, =24000 // arm clock = 96000000hz
1
		subs r1, r1, #1
		bne  %B1
		subs r0, r0, #1
		bne  %B0
		bx	 lr
}

void Gpio_Init(void)
{
    /* Define the init structure for the output LED pin*/
    gpio_pin_config_t led_config = {
        kGPIO_DigitalOutput, 0,
    };
	
    /* Init output LED GPIO. */
    GPIO_PinInit(GPIO, 0, 15, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 15, 0);
    GPIO_PinInit(GPIO, 0, 19, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 19, 0);
    GPIO_PinInit(GPIO, 0, 21, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 21, 0);
    GPIO_PinInit(GPIO, 0, 22, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 22, 0);
    GPIO_PinInit(GPIO, 0, 25, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 25, 1);
    GPIO_PinInit(GPIO, 0, 26, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 26, 1);
    GPIO_PinInit(GPIO, 0, 29, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 29, 1);
    GPIO_PinInit(GPIO, 0, 30, &led_config);
    GPIO_WritePinOutput(GPIO, 0, 30, 1);		
}

int main()
{
	uint32_t i;
	FATFS fs;
	FIL file;
	FRESULT Res;	
	uint32_t TimeCount;
	uint32_t ByteWrite, ByteRead;

    /* Board pin, clock, debug console init */
    /* attach 12 MHz clock to FLEXCOMM0 (debug console) */
    CLOCK_AttachClk(BOARD_DEBUG_UART_CLK_ATTACH);
    /* enable clock for GPIO*/
    CLOCK_EnableClock(kCLOCK_Gpio0);
    CLOCK_EnableClock(kCLOCK_Gpio1);

    BOARD_InitPins();
    BOARD_BootClockFROHF96M();
    BOARD_InitDebugConsole();	
	
	Gpio_Init();
	
	f_mount(&fs, "4:" , 0);	
/*	Res = f_mkfs("", 0, 4096);
	if (Res != RES_OK) {
		PRINTF("f_mkfs error %d\r\n", Res);
		while(1);
	}
*/
	PRINTF("Writing test.bin, file sise 10MB\r\n");
 	Res = f_open(&file, "4:test.bin", FA_WRITE | FA_CREATE_ALWAYS);
	if (Res != RES_OK) {
		PRINTF("Create file failed\r\n");
		while(1) {
			GPIO_TogglePinsOutput(GPIO, 0, 1u << 15);
			Delay_ms(300);			
		}	
	}
	for (i=0; i<sizeof(TestBuffer); i++) {
		TestBuffer[i] = i;
	}
	TimeCount = timer_get_current_milliseconds();
	for (i=0; i<10*1024*1024/sizeof(TestBuffer); i++) {
		Res = f_write(&file, &TestBuffer, sizeof(TestBuffer), &ByteWrite);	
		if (Res != RES_OK) {
			f_close(&file);
			PRINTF("Write file error\r\n");
			while(1) {
				GPIO_TogglePinsOutput(GPIO, 0, 1u << 15);
				Delay_ms(300);			
			}	
		}		
	}
	f_close(&file);
	PRINTF("Sd write speed %d KB/s\r\n", 10*1024*1024/(timer_get_current_milliseconds()-TimeCount));
	
	PRINTF("Reading test.bin, file sise 10MB\r\n");
	Res =  f_open(&file, "4:test.bin", FA_READ | FA_OPEN_EXISTING);
	if (Res != RES_OK) {
		PRINTF("Open file failed\r\n");
		while(1) {
			GPIO_TogglePinsOutput(GPIO, 0, 1u << 15);
			Delay_ms(300);			
		}			
	}
	TimeCount = timer_get_current_milliseconds();
	for (i=0; i<10*1024*1024/sizeof(TestBuffer); i++) {
		Res = f_read(&file, (unsigned char *)&TestBuffer, sizeof(TestBuffer), &ByteRead);
		if (Res != RES_OK) {
			f_close(&file);
			PRINTF("Read file error\r\n");
			while(1) {
				GPIO_TogglePinsOutput(GPIO, 0, 1u << 15);
				Delay_ms(300);			
			}		
		}			
	}
	f_close(&file);
	PRINTF("Sd read speed %d KB/s\r\n", 10*1024*1024/(timer_get_current_milliseconds()-TimeCount));

	while(1) {
		GPIO_TogglePinsOutput(GPIO, 0, 1u << 15);
		Delay_ms(1000);
	}
}
