/*
 * Copyright (c) 2015, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of the copyright holder nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * TEXT BELOW IS USED AS SETTING FOR THE PINS TOOL *****************************
PinsProfile:
- !!product 'Pins v2.0'
- !!processor 'LPC54114J256'
- !!package 'LPC54114J256BD64'
- !!mcu_data 'ksdk2_0'
- !!processor_version '1.1.0'
 * BE CAREFUL MODIFYING THIS COMMENT - IT IS YAML SETTINGS FOR THE PINS TOOL ***
 */

#include "fsl_common.h"
#include "fsl_iocon.h"
#include "pin_mux.h"

/*FUNCTION**********************************************************************
 *
 * Function Name : BOARD_InitPins
 * Description   : Configures pin routing and optionally pin electrical features.
 *
 *END**************************************************************************/
void BOARD_InitPins(void) { /* Function assigned for the Core #0 (ARM Cortex-M4) */
	CLOCK_EnableClock(kCLOCK_Iocon);                           /* Enables the clock for the IOCON block. 0 = Disable; 1 = Enable.: 0x01u */

	// USART FC0
	const uint32_t usart_config = (
		IOCON_FUNC1 |
		IOCON_MODE_INACT |
		IOCON_DIGITAL_EN | 
		IOCON_INPFILT_OFF
	);
	IOCON_PinMuxSet(IOCON, 0, 0, usart_config); // PIO0_0 RXD
	IOCON_PinMuxSet(IOCON, 0, 1, usart_config); // PIO0_1 TXD	
	
	// leds
	const uint32_t leds_config = {
		IOCON_FUNC0 | 
		IOCON_MODE_INACT | 		
		IOCON_DIGITAL_EN | 
		IOCON_INPFILT_OFF		
	};
	IOCON_PinMuxSet(IOCON, 0, 15, leds_config);
	IOCON_PinMuxSet(IOCON, 0, 19, leds_config);
	IOCON_PinMuxSet(IOCON, 0, 21, leds_config);
	IOCON_PinMuxSet(IOCON, 0, 22, leds_config);
	IOCON_PinMuxSet(IOCON, 0, 25, leds_config | IOCON_GPIO_MODE);
	IOCON_PinMuxSet(IOCON, 0, 26, leds_config | IOCON_GPIO_MODE);
	IOCON_PinMuxSet(IOCON, 0, 29, leds_config);
	IOCON_PinMuxSet(IOCON, 0, 30, leds_config);
	
	// sd
	uint32_t spi_config = {
		IOCON_FUNC1 | 
		IOCON_MODE_INACT | 		
		IOCON_DIGITAL_EN | 
		IOCON_INPFILT_OFF			
	};
	IOCON_PinMuxSet(IOCON, 0, 8, spi_config); // PIO0_8 FC2_RXD_SDA_MOSI 
	IOCON_PinMuxSet(IOCON, 0, 9, spi_config); // PIO0_9 FC2_TXD_SCL_MISO
	IOCON_PinMuxSet(IOCON, 0, 10, spi_config); // PIO0_10 FC2_SCK
	spi_config &= ~7;
	spi_config |= IOCON_FUNC2;
	IOCON_PinMuxSet(IOCON, 0, 3, spi_config); // PIO0_3 FC2_SSEL3
}

/*******************************************************************************
 * EOF
 ******************************************************************************/
